[−][src]Enum ffi_support::handle_map::HandleError
An error representing the ways a Handle may be invalid.
Variants
NullHandleIdentical to invalid handle, but has a slightly more helpful message for the most common case 0.
InvalidHandleReturned from Handle::from_u64 if Handle::is_valid fails.
StaleVersionReturned from get/get_mut/delete if the handle is stale (this indicates something equivalent to a use-after-free / double-free, etc).
IndexPastEndReturned if the handle index references an index past the end of the HandleMap.
WrongMapThe handle has a map_id for a different map than the one it was attempted to be used with.